#!/bin/bash

# Find directory where script is stored.
# http://stackoverflow.com/a/246128/882209
SOURCE="${BASH_SOURCE[0]}"
while [ -h "$SOURCE" ]; do
  DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
  SOURCE="$(readlink "$SOURCE")"
  [[ ${SOURCE} != /* ]] && SOURCE="$DIR/$SOURCE"
done
DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"

# Define log directory.

if [ -n "$SAYMON_LOCAL_AGENT_LOGBACK_CONFIGURATION_FILE" ] ; then
  SAYMON_AGENT_LOGBACK_CONFIGURATION_FILE=${SAYMON_LOCAL_AGENT_LOGBACK_CONFIGURATION_FILE}
fi

if [ -z "$SAYMON_AGENT_LOGBACK_CONFIGURATION_FILE" ] ; then
  SAYMON_AGENT_LOGBACK_CONFIGURATION_FILE="$DIR/conf/logback.xml"
fi

# Define update directory.

if [ -n "$SAYMON_LOCAL_AGENT_UPDATE_DIRECTORY" ] ; then
  SAYMON_AGENT_UPDATE_DIRECTORY=${SAYMON_LOCAL_AGENT_UPDATE_DIRECTORY}
fi

if [ -z "$SAYMON_AGENT_UPDATE_DIRECTORY" ] ; then
  SAYMON_AGENT_UPDATE_DIRECTORY="/tmp"
fi

# Define PID file.

if [ -n "$SAYMON_LOCAL_AGENT_PID_FILE" ] ; then
  SAYMON_AGENT_PID_FILE=${SAYMON_LOCAL_AGENT_PID_FILE}
fi

if [ -z "$SAYMON_AGENT_PID_FILE" ] ; then
  SAYMON_AGENT_PID_FILE="$DIR/saymon-agent.pid"
fi

# Define config file name.

if [ -f "$DIR/conf/local-agent.properties" ] ; then
  SAYMON_AGENT_CONFIG_NAME="$DIR/conf/local-agent.properties"
else
  SAYMON_AGENT_CONFIG_NAME="$DIR/conf/agent.properties"
fi

JAVA="java"

# Use bundled JRE if available (Linux).
if [ -x "$DIR/jre/bin/java" ] ; then
  echo "Using bundled JRE from $DIR/jre"
  JAVA="$DIR/jre/bin/java"
fi

# Use bundled JRE if available (MacOS).
if [ -x "$DIR/jre/Contents/Home/bin/java" ] ; then
  echo "Using bundled JRE from $DIR/jre"
  JAVA="$DIR/jre/Contents/Home/bin/java"
fi

TMP_UPDATE_DIRECTORY="$SAYMON_AGENT_UPDATE_DIRECTORY/saymon-agent"

# If update exists, copy it to working directory and delete it.
if [ -d "$TMP_UPDATE_DIRECTORY" ]; then
  cp -rf $TMP_UPDATE_DIRECTORY/* $DIR
  rm -rf $TMP_UPDATE_DIRECTORY
fi

# Run java in accordance with it's profile settings.
LC_NUMERIC=C ${JAVA} -DSAYMON_AGENT_CONFIG_NAME="$SAYMON_AGENT_CONFIG_NAME" \
  -DSAYMON_AGENT_TMP_UPDATE_DIRECTORY="$TMP_UPDATE_DIRECTORY" \
  -DSAYMON_AGENT_PID_FILE="$SAYMON_AGENT_PID_FILE" \
  -Djava.library.path="$DIR/lib" \
  -Dlogback.configurationFile="$SAYMON_AGENT_LOGBACK_CONFIGURATION_FILE" \
  -Dfile.encoding=UTF-8 \
  -jar "$DIR/saymon-agent.jar"

# Forward java exit code.
exit $?